Index: applications/editors/josm/plugins/CommandLine/build.xml
===================================================================
--- applications/editors/josm/plugins/CommandLine/build.xml	(revision 30318)
+++ applications/editors/josm/plugins/CommandLine/build.xml	(revision 30319)
@@ -4,5 +4,5 @@
     <property name="commit.message" value="JOSM/CommandLine: fix exception after JOSM update"/>
     <!-- enter the *lowest* JOSM version this plugin is currently compatible with -->
-    <property name="plugin.main.version" value="6690"/>
+    <property name="plugin.main.version" value="6906"/>
 
     <!-- Configure these properties (replace "..." accordingly).
Index: applications/editors/josm/plugins/CommandLine/src/CommandLine/OsmToCmd.java
===================================================================
--- applications/editors/josm/plugins/CommandLine/src/CommandLine/OsmToCmd.java	(revision 30318)
+++ applications/editors/josm/plugins/CommandLine/src/CommandLine/OsmToCmd.java	(revision 30319)
@@ -41,7 +41,7 @@
 import org.openstreetmap.josm.data.osm.WayData;
 import org.openstreetmap.josm.io.IllegalDataException;
-import org.openstreetmap.josm.io.OsmDataParsingException;
 import org.openstreetmap.josm.io.UTFInputStreamReader;
 import org.openstreetmap.josm.tools.DateUtils;
+import org.openstreetmap.josm.tools.XmlParsingException;
 import org.xml.sax.Attributes;
 import org.xml.sax.InputSource;
@@ -94,6 +94,6 @@
         }
 
-        protected void throwException(String msg) throws OsmDataParsingException {
-            throw new OsmDataParsingException(msg).rememberLocation(locator);
+        protected void throwException(String msg) throws XmlParsingException {
+            throw new XmlParsingException(msg).rememberLocation(locator);
         }
 
Index: applications/editors/josm/plugins/reverter/build.xml
===================================================================
--- applications/editors/josm/plugins/reverter/build.xml	(revision 30318)
+++ applications/editors/josm/plugins/reverter/build.xml	(revision 30319)
@@ -4,5 +4,5 @@
     <property name="commit.message" value="Reverter: Update MultiOsmReader to support null data after redaction"/>
     <!-- enter the *lowest* JOSM version this plugin is currently compatible with -->
-    <property name="plugin.main.version" value="6887"/>
+    <property name="plugin.main.version" value="6906"/>
 
     <!-- Configure these properties (replace "..." accordingly).
Index: applications/editors/josm/plugins/reverter/src/reverter/corehacks/OsmServerChangesetReader.java
===================================================================
--- applications/editors/josm/plugins/reverter/src/reverter/corehacks/OsmServerChangesetReader.java	(revision 30318)
+++ applications/editors/josm/plugins/reverter/src/reverter/corehacks/OsmServerChangesetReader.java	(revision 30319)
@@ -21,8 +21,8 @@
 import org.openstreetmap.josm.io.IllegalDataException;
 import org.openstreetmap.josm.io.OsmChangesetParser;
-import org.openstreetmap.josm.io.OsmDataParsingException;
 import org.openstreetmap.josm.io.OsmServerReader;
 import org.openstreetmap.josm.io.OsmTransferException;
 import org.openstreetmap.josm.tools.CheckParameterUtil;
+import org.openstreetmap.josm.tools.XmlParsingException;
 
 /**
@@ -194,5 +194,5 @@
         } catch(UnsupportedEncodingException e) {
             throw new OsmTransferException(e);
-        } catch(OsmDataParsingException e) {
+        } catch(XmlParsingException e) {
             throw new OsmTransferException(e);
         } finally {
Index: applications/editors/josm/plugins/roadsigns/build.xml
===================================================================
--- applications/editors/josm/plugins/roadsigns/build.xml	(revision 30318)
+++ applications/editors/josm/plugins/roadsigns/build.xml	(revision 30319)
@@ -4,5 +4,5 @@
     <property name="commit.message" value="preset maintenance (Fahrradstraße)"/>
     <!-- enter the *lowest* JOSM version this plugin is currently compatible with -->
-    <property name="plugin.main.version" value="6340"/>
+    <property name="plugin.main.version" value="6906"/>
 
     <!--
Index: applications/editors/josm/plugins/roadsigns/src/org/openstreetmap/josm/plugins/roadsigns/RoadSignsReader.java
===================================================================
--- applications/editors/josm/plugins/roadsigns/src/org/openstreetmap/josm/plugins/roadsigns/RoadSignsReader.java	(revision 30318)
+++ applications/editors/josm/plugins/roadsigns/src/org/openstreetmap/josm/plugins/roadsigns/RoadSignsReader.java	(revision 30319)
@@ -21,7 +21,5 @@
 import org.xml.sax.SAXParseException;
 import org.xml.sax.helpers.DefaultHandler;
-
 import org.openstreetmap.josm.Main;
-import org.openstreetmap.josm.io.OsmDataParsingException;
 import org.openstreetmap.josm.plugins.roadsigns.Sign.SignParameter;
 import org.openstreetmap.josm.plugins.roadsigns.Sign.Tag;
@@ -29,4 +27,5 @@
 import org.openstreetmap.josm.plugins.roadsigns.javacc.TokenMgrError;
 import org.openstreetmap.josm.tools.LanguageInfo;
+import org.openstreetmap.josm.tools.XmlParsingException;
 
 /**
@@ -202,5 +201,5 @@
         }
 
-        private String getMandatoryAttribute(Attributes atts, String ident) throws OsmDataParsingException {
+        private String getMandatoryAttribute(Attributes atts, String ident) throws XmlParsingException {
             String result = atts.getValue(ident);
             if (result == null) {
@@ -223,6 +222,6 @@
             throw new ExtendedParsingException(e).rememberLocation(locator);
         }
-        protected void throwException(String msg) throws OsmDataParsingException {
-            throw new OsmDataParsingException(msg).rememberLocation(locator);
+        protected void throwException(String msg) throws XmlParsingException {
+            throw new XmlParsingException(msg).rememberLocation(locator);
         }
 
@@ -230,9 +229,9 @@
             try {
                 throwException(s);
-            } catch (OsmDataParsingException ex) {
+            } catch (XmlParsingException ex) {
                 System.err.println("Warning: "+ex.getMessage());
             }
         }
-        public void wireSupplements() throws OsmDataParsingException {
+        public void wireSupplements() throws XmlParsingException {
             Map<String, Sign> map = new HashMap<String, Sign>();
             for (Sign sign : allSigns) {

Index: applications/editors/josm/plugins/reverter/src/reverter/corehacks/OsmChangesetContentParser.java
===================================================================
--- applications/editors/josm/plugins/reverter/src/reverter/corehacks/OsmChangesetContentParser.java	(revision 30318)
+++ applications/editors/josm/plugins/reverter/src/reverter/corehacks/OsmChangesetContentParser.java	(revision 30319)
@@ -24,7 +24,7 @@
 import org.openstreetmap.josm.gui.progress.NullProgressMonitor;
 import org.openstreetmap.josm.gui.progress.ProgressMonitor;
-import org.openstreetmap.josm.io.OsmDataParsingException;
 import org.openstreetmap.josm.tools.CheckParameterUtil;
 import org.openstreetmap.josm.tools.DateUtils;
+import org.openstreetmap.josm.tools.XmlParsingException;
 import org.xml.sax.Attributes;
 import org.xml.sax.InputSource;
@@ -59,17 +59,17 @@
         }
 
-        protected void throwException(String message) throws OsmDataParsingException {
-            throw new OsmDataParsingException(
+        protected void throwException(String message) throws XmlParsingException {
+            throw new XmlParsingException(
                     message
             ).rememberLocation(locator);
         }
 
-        protected void throwException(Exception e) throws OsmDataParsingException {
-            throw new OsmDataParsingException(
+        protected void throwException(Exception e) throws XmlParsingException {
+            throw new XmlParsingException(
                     e
             ).rememberLocation(locator);
         }
 
-        protected long getMandatoryAttributeLong(Attributes attr, String name) throws SAXException{
+        protected long getMandatoryAttributeLong(Attributes attr, String name) throws SAXException {
             String v = attr.getValue(name);
             if (v == null) {
@@ -300,8 +300,7 @@
      * if null
      * @return the parsed data
      * @throws OsmDataParsingException thrown if something went wrong. Check for chained
      * exceptions.
      */
-    public ChangesetDataSet parse(ProgressMonitor progressMonitor) throws OsmDataParsingException {
+    public ChangesetDataSet parse(ProgressMonitor progressMonitor) throws XmlParsingException {
         if (progressMonitor == null) {
             progressMonitor = NullProgressMonitor.INSTANCE;
@@ -311,12 +310,12 @@
             progressMonitor.indeterminateSubTask(tr("Parsing changeset content ..."));
             SAXParserFactory.newInstance().newSAXParser().parse(source, new Parser());
-        } catch(OsmDataParsingException e){
+        } catch(XmlParsingException e){
             throw e;
         } catch (ParserConfigurationException e) {
-            throw new OsmDataParsingException(e);
+            throw new XmlParsingException(e);
         } catch(SAXException e) {
-            throw new OsmDataParsingException(e);
+            throw new XmlParsingException(e);
         } catch(IOException e) {
-            throw new OsmDataParsingException(e);
+            throw new XmlParsingException(e);
         } finally {
             progressMonitor.finishTask();
@@ -329,8 +328,7 @@
      *
      * @return the parsed data
      * @throws OsmDataParsingException thrown if something went wrong. Check for chained
      * exceptions.
      */
-    public ChangesetDataSet parse() throws OsmDataParsingException {
+    public ChangesetDataSet parse() throws XmlParsingException {
         return parse(null);
     }
@@ -300,8 +300,7 @@
      * if null
      * @return the parsed data
-     * @throws OsmDataParsingException thrown if something went wrong. Check for chained
-     * exceptions.
+     * @throws XmlParsingException if something went wrong. Check for chained exceptions.
      */
@@ -329,8 +328,7 @@
      *
      * @return the parsed data
-     * @throws OsmDataParsingException thrown if something went wrong. Check for chained
-     * exceptions.
+     * @throws XmlParsingException if something went wrong. Check for chained exceptions.
      */